@@ -75,9 +75,9 @@ class TrackSegmentFinderHourglas:
 
         result = (hitline4 and hitline3 and hitline2 and hitline1 and  lr) or \
                  (hitline5 and hitline3 and hitline2 and hitline1 and  lr) or \
+                 (hitline5 and hitline4 and hitline2 and hitline1 and  lr) or \
                  (hitline5 and hitline4 and hitline3 and hitline1 and  lr) or \
                  (hitline5 and hitline4 and hitline3 and hitline2 and  lr) or \
-                 (hitline5 and hitline4 and hitline3 and hitline2 and  lr) or \
                  (hitline5 and hitline4 and hitline3 and hitline2 and hitline1 and lr)
 
         return result
@@ -129,60 +129,60 @@ class TrackSegmentFinderHourglas:
             # Circulation counterclockwise - successor left, predecessor right
             # Add 0 element as placeholder for lr value
             hit_bin[0] = list(map(int,[seg_act[4,2],seg_act[4,1],seg_act[4,0],seg_pre[4,15],seg_pre[4,14],
-                                       seg_act[3,1],seg_act[3,0],seg_pre[3,15],seg_pre[3,14],
+                                       seg_act[3,2],seg_act[3,1],seg_act[3,0],seg_pre[3,15],
                                        seg_act[2,1],seg_act[2,0],seg_pre[2,15],
-                                       seg_act[1,0],seg_pre[1,15],
+                                       seg_act[1,1],seg_act[1,0],
                                        seg_act[0,0],
                                        0]))
             hit_bin[1] = list(map(int,[seg_act[4,3],seg_act[4,2],seg_act[4,1],seg_act[4,0],seg_pre[4,15],
-                                       seg_act[3,2],seg_act[3,1],seg_act[3,0],seg_pre[3,15],
+                                       seg_act[3,3],seg_act[3,2],seg_act[3,1],seg_act[3,0],
                                        seg_act[2,2],seg_act[2,1],seg_act[2,0],
-                                       seg_act[1,1],seg_act[1,0],
+                                       seg_act[1,2],seg_act[1,1],
                                        seg_act[0,1],
                                        0]))
             hit_bin[14] =  list(map(int,[seg_suc[4,0],seg_act[4,15],seg_act[4,14],seg_act[4,13],seg_act[4,12],
-                                         seg_act[3,15],seg_act[3,14],seg_act[3,13],seg_act[3,12],
+                                         seg_suc[3,0],seg_act[3,15],seg_act[3,14],seg_act[3,13],
                                          seg_act[2,15],seg_act[2,14],seg_act[2,13],
-                                         seg_act[1,14],seg_act[1,13],
+                                         seg_act[1,15],seg_act[1,14],
                                          seg_act[0,14],
                                          0]))
             hit_bin[15] =  list(map(int,[seg_suc[4,1],seg_suc[4,0],seg_act[4,15],seg_act[4,14],seg_act[4,13],
-                                         seg_suc[3,0],seg_act[3,15],seg_act[3,14],seg_act[3,13],
+                                         seg_suc[3,1],seg_suc[3,0],seg_act[3,15],seg_act[3,14],
                                          seg_suc[2,0],seg_act[2,15],seg_act[2,14],
-                                         seg_act[1,15],seg_act[1,14],
+                                         seg_suc[1,0],seg_act[1,15],
                                          seg_act[0,15],
                                          0]))
         else:
             hit_bin[0] = list(map(int,[seg_act[4,2],seg_act[4,1],seg_act[4,0],0,0,
-                                       seg_act[3,1],seg_act[3,0],0,0,
+                                       seg_act[3,2],seg_act[3,1],seg_act[3,0],0,
                                        seg_act[2,1],seg_act[2,0],0,
-                                       seg_act[1,0],0,
+                                       seg_act[1,1],seg_act[1,0],
                                        seg_act[0,0],
                                        0]))
             hit_bin[1] = list(map(int,[seg_act[4,3],seg_act[4,2],seg_act[4,1],seg_act[4,0],0,
-                                       seg_act[3,2],seg_act[3,1],seg_act[3,0],0,
+                                       seg_act[3,3],seg_act[3,2],seg_act[3,1],seg_act[3,0],
                                        seg_act[2,2],seg_act[2,1],seg_act[2,0],
-                                       seg_act[1,1],seg_act[1,0],
+                                       seg_act[1,2],seg_act[1,1],
                                        seg_act[0,1],
                                        0]))
             hit_bin[14] =  list(map(int,[0,seg_act[4,15],seg_act[4,14],seg_act[4,13],seg_act[4,12],
-                                         seg_act[3,15],seg_act[3,14],seg_act[3,13],seg_act[3,12],
+                                         0,seg_act[3,15],seg_act[3,14],seg_act[3,13],
                                          seg_act[2,15],seg_act[2,14],seg_act[2,13],
-                                         seg_act[1,14],seg_act[1,13],
+                                         seg_act[1,15],seg_act[1,14],
                                          seg_act[0,14],
                                          0]))
             hit_bin[15] =  list(map(int,[0,0,seg_act[4,15],seg_act[4,14],seg_act[4,13],
-                                         0,seg_act[3,15],seg_act[3,14],seg_act[3,13],
+                                         0,0,seg_act[3,15],seg_act[3,14],
                                          0,seg_act[2,15],seg_act[2,14],
-                                         seg_act[1,15],seg_act[1,14],
+                                         0,seg_act[1,15],
                                          seg_act[0,15],
                                          0]))
 
         for i in range(2,16-2):
             hit_bin[i] =  list(map(int,[seg_act[4,i+2],seg_act[4,i+1],seg_act[4,i],seg_act[4,i-1],seg_act[4,i-2],
-                                        seg_act[3,i+1],seg_act[3,i],seg_act[3,i-1],seg_act[3,i-2],
+                                        seg_act[3,i+2],seg_act[3,i+1],seg_act[3,i],seg_act[3,i-1],
                                         seg_act[2,i+1],seg_act[2,i],seg_act[2,i-1],
-                                        seg_act[1,i],seg_act[1,i-1],
+                                        seg_act[1,i+1],seg_act[1,i],
                                         seg_act[0,i],
                                         0]))
         return hit_bin
@@ -357,15 +357,15 @@ class TrackSegmentFinderHourglas:
                         layer_segments[segment_id,4,0] = 1
                         layer_segments[segment_id,4,1] = 1
                         layer_segments[segment_id,4,2] = 1
-                        layer_segments[segment_id-1,3,14] = 1
                         layer_segments[segment_id-1,3,15] = 1
                         layer_segments[segment_id,3,0] = 1
                         layer_segments[segment_id,3,1] = 1
+                        layer_segments[segment_id,3,2] = 1
                         layer_segments[segment_id-1,2,15] = 1
                         layer_segments[segment_id,2,0] = 1
                         layer_segments[segment_id,2,1] = 1
-                        layer_segments[segment_id-1,1,15] = 1
                         layer_segments[segment_id,1,0] = 1
+                        layer_segments[segment_id,1,1] = 1
                         layer_segments[segment_id,0,0] = 1
                     elif(j==1):
                         layer_segments[segment_id-1,4,15] = 1
@@ -373,15 +373,15 @@ class TrackSegmentFinderHourglas:
                         layer_segments[segment_id,4,1] = 1
                         layer_segments[segment_id,4,2] = 1
                         layer_segments[segment_id,4,3] = 1
-                        layer_segments[segment_id-1,3,15] = 1
                         layer_segments[segment_id,3,0] = 1
                         layer_segments[segment_id,3,1] = 1
                         layer_segments[segment_id,3,2] = 1
+                        layer_segments[segment_id,3,3] = 1
                         layer_segments[segment_id,2,0] = 1
                         layer_segments[segment_id,2,1] = 1
                         layer_segments[segment_id,2,2] = 1
-                        layer_segments[segment_id,1,0] = 1
                         layer_segments[segment_id,1,1] = 1
+                        layer_segments[segment_id,1,2] = 1
                         layer_segments[segment_id,0,1] = 1
                     elif(j==14):
                         layer_segments[segment_id,4,12] = 1
@@ -389,15 +389,15 @@ class TrackSegmentFinderHourglas:
                         layer_segments[segment_id,4,14] = 1
                         layer_segments[segment_id,4,15] = 1
                         layer_segments[segment_id+1 % layer_in.n_segs,4,0] = 1
-                        layer_segments[segment_id,3,12] = 1
                         layer_segments[segment_id,3,13] = 1
                         layer_segments[segment_id,3,14] = 1
                         layer_segments[segment_id,3,15] = 1
+                        layer_segments[segment_id+1 % layer_in.n_segs,3,0] = 1
                         layer_segments[segment_id,2,13] = 1
                         layer_segments[segment_id,2,14] = 1
                         layer_segments[segment_id,2,15] = 1
-                        layer_segments[segment_id,1,13] = 1
                         layer_segments[segment_id,1,14] = 1
+                        layer_segments[segment_id,1,15] = 1
                         layer_segments[segment_id,0,14] = 1
                     elif(j==15):
                         layer_segments[segment_id,4,13] = 1
@@ -405,15 +405,15 @@ class TrackSegmentFinderHourglas:
                         layer_segments[segment_id,4,15] = 1
                         layer_segments[segment_id+1 % layer_in.n_segs,4,0] = 1
                         layer_segments[segment_id+1 % layer_in.n_segs,4,1] = 1
-                        layer_segments[segment_id,3,13] = 1
                         layer_segments[segment_id,3,14] = 1
                         layer_segments[segment_id,3,15] = 1
                         layer_segments[segment_id+1 % layer_in.n_segs,3,0] = 1
+                        layer_segments[segment_id+1 % layer_in.n_segs,3,1] = 1
                         layer_segments[segment_id,2,14] = 1
                         layer_segments[segment_id,2,15] = 1
                         layer_segments[segment_id+1 % layer_in.n_segs,2,0] = 1
-                        layer_segments[segment_id,1,14] = 1
                         layer_segments[segment_id,1,15] = 1
+                        layer_segments[segment_id+1 % layer_in.n_segs,1,0] = 1
                         layer_segments[segment_id,0,15] = 1
                     else:
                         layer_segments[segment_id,4,j-2] = 1
@@ -421,15 +421,15 @@ class TrackSegmentFinderHourglas:
                         layer_segments[segment_id,4,j] = 1
                         layer_segments[segment_id,4,j+1] = 1
                         layer_segments[segment_id,4,j+2] = 1
-                        layer_segments[segment_id,3,j-2] = 1
                         layer_segments[segment_id,3,j-1] = 1
                         layer_segments[segment_id,3,j] = 1
                         layer_segments[segment_id,3,j+1] = 1
+                        layer_segments[segment_id,3,j+2] = 1
                         layer_segments[segment_id,2,j-1] = 1
                         layer_segments[segment_id,2,j] = 1
                         layer_segments[segment_id,2,j+1] = 1
-                        layer_segments[segment_id,1,j-1] = 1
                         layer_segments[segment_id,1,j] = 1
+                        layer_segments[segment_id,1,j+1] = 1
                         layer_segments[segment_id,0,j] = 1
 
         for layer_id in range(1,9):
@@ -488,7 +488,7 @@ class TrackSegmentFinderHourglas:
         frame_out = None
         if(mode == 'hits'):
             self.mode = 'hits'
-            frame_out = self._detect_hit_outers(frame_in,edge_hit)
+            frame_out = self._detect_hits(frame_in,edge_hit)
         elif(mode == 'candidates'):
             self._mode = 'candidates'
             frame_out = self._detect_candidates(frame_in,edge_hit)
